@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
+import ast
+from pprint import pprint
+
 import click
 
+from ytscraper.helper.configfile import DEFAULT_OPTIONS, load_config, write_config
 from ytscraper.helper.echo import echov, echow
-from ytscraper.helper.configfile import load_config, write_config
-from ytscraper.helper.configfile import DEFAULT_OPTIONS
-from pprint import pprint
-import ast
 
 
 @click.group()
@@ -42,7 +42,7 @@ def set(context, option, value):
     target_type = type(DEFAULT_OPTIONS[option])
     if not isinstance(value, target_type):
         raise click.BadArgumentUsage(
-            f"Given value '{value}' is not a valid type for '{option}'. Please provide a '{target_type.__name__}'."
+            f"Given value '{value}' is not a valid type for '{option}'. Please provide type '{target_type.__name__}'."
         )
     elif target_type is int and value < 0:
         raise click.BadArgumentUsage(
