@@ -1,36 +1,36 @@
 #!/usr/bin/env python
 import csv
 import os
-import sys
 import re
+import sys
 
 
 def export_to_csv(nodes, output_dir):
     nodes_path = os.path.join(output_dir, "nodes.csv")
     edges_path = os.path.join(output_dir, "edges.csv")
+    node_path_exists = os.path.exists(nodes_path)
+    edge_path_exists = os.path.exists(edges_path)
 
     edges = set(
         (node["videoId"], child) for node in nodes for child in node["relatedVideos"]
     )
-    with open(edges_path, "w", newline="") as out:
+    with open(edges_path, "a", newline="") as out:
         csv_out = csv.writer(out, delimiter="\t")
-        csv_out.writerow(["origin", "target"])
+        if not edge_path_exists:
+            csv_out.writerow(["origin", "target"])
         for origin, target in edges:
             csv_out.writerow([origin, target])
 
-    with open(nodes_path, "w", newline="") as out:
+    with open(nodes_path, "a", newline="") as out:
         csv_out = csv.writer(out, delimiter="\t")
-        csv_out.writerow(nodes[0].keys())
+        if not node_path_exists:
+            csv_out.writerow(nodes[0].keys())
         for node in nodes:
             del node["relatedVideos"]
             del node["description"]
             csv_out.writerow(node.values())
 
 
-def get_call_directory():
-    return os.path.dirname(sys.argv[0])
-
-
 def filter_text(text, encoding="ascii"):
     if encoding == "smart":
         text = re.sub(r"<[^>]*>", " ", text)
